@@ -1,12 +1,12 @@
 package TAP::Parser::Iterator::PherkinStream;
-$TAP::Parser::Iterator::PherkinStream::VERSION = '0.78';
+$TAP::Parser::Iterator::PherkinStream::VERSION = '0.79';
 =head1 NAME
 
 TAP::Parser::Iterator::PherkinStream - Stream with TAP from async BDD process
 
 =head1 VERSION
 
-version 0.78
+version 0.79
 
 =cut
 
@@ -114,7 +114,7 @@ sub get_select_handles {
     my $self = shift;
 
     # return our handle in case it's a socket or pipe (select()-able)
-    return ( $self->{fh}, $self->{err_fh});
+    return ( $self->{out_fh}, $self->{err_fh});
 }
 
 
